@@ -1,4 +1,3 @@
-import warnings
 import uuid
 import json
 import time
@@ -6,7 +5,6 @@ import os
 
 import requests
 import pandas as pd
-import numpy as np
 from io import BytesIO, StringIO
 
 class Client(object):
@@ -19,8 +17,7 @@ class Client(object):
         This file should have the service URL on line 1,
         the username on line 2,
         and the API key on line 3.
-        To use the .aionics_key file, provide no arguments.
-        To ignore the .aionics_key file, provide all three arguments.
+        Initialization arguments take precedence over key file entries. 
 
         Parameters
         ----------
@@ -33,7 +30,13 @@ class Client(object):
         """
         super(Client,self).__init__()
 
-        if not service_url and not username and not api_key:
+        if not service_url or not username or not api_key:
+            if service_url:
+                raise RuntimeError('A username and api_key are required')
+            if username:
+                raise RuntimeError('A service_url and api_key are required')
+            if api_key:
+                raise RuntimeError('A service_url and username are required')
             homedir = os.path.expanduser('~')
             hostfile = os.path.join(homedir,'.aionics_key')
             with open(hostfile,'r') as f:
